# Workspace Provisioning from SAP for Me
Learn how to provision workspaces in SAP LeanIX using SAP for Me.
Find all relevant information for workspace provisioning here.
  * Classic provisioning process, see [Provisioning SAP LeanIX from SAP for Me (classic)](https://help.sap.com/docs/leanix/ea/workspace-provisioning?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to provision workspaces in SAP LeanIX using SAP for Me.")
  * NGCS provisioning process, see [Provisioning SAP LeanIX from SAP for Me (NGCS)](https://help.sap.com/docs/leanix/ea/provisioning-sap-leanix-workspace?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to provision workspaces in SAP LeanIX using SAP for Me.")
  * Super/cloud admin for workspace provisioning, see [SAP for Me Super/Cloud Admin for Workspace Provisioning](https://help.sap.com/docs/leanix/ea/sap-for-me-super-cloud-admin-for-workspace-provisioning?locale=en-US&state=PRODUCTION&version=CLOUD "The cloud administrator acts as the main IT contact during SAP LeanIX workspace provisioning. They receive key onboarding and provisioning emails from SAP and are responsible for creating and managing additional S‑users for successful access.")


YesNo
Send
